#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pantry
version:              0.8.3
visibility:           public
id:                   pantry-0.8.3-Jn6VY85qXoxHjXWTfuRpVO
key:                  pantry-0.8.3-Jn6VY85qXoxHjXWTfuRpVO
license:              BSD-3-Clause
copyright:            2018-2022 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/pantry#readme
synopsis:             Content addressable Haskell package management
description:
    Please see the README on GitHub at <https://github.com/commercialhaskell/pantry#readme>

category:             Development
abi:                  bdc4db40dc8f76ddb86983c80673d882
exposed:              True
exposed-modules:
    Pantry Pantry.Internal Pantry.Internal.AesonExtended
    Pantry.Internal.Companion Pantry.Internal.Stackage
    Pantry.Internal.StaticBytes Pantry.SHA256

hidden-modules:
    Hackage.Security.Client.Repository.HttpLib.HttpClient
    Pantry.Archive Pantry.HTTP Pantry.HPack Pantry.Hackage Pantry.Repo
    Pantry.SQLite Pantry.Storage Pantry.Casa Pantry.Tree Pantry.Types
    System.IsWindows

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pantry
hs-libraries:         HSpantry-0.8.3-Jn6VY85qXoxHjXWTfuRpVO
depends:
    Cabal-3.10.3.0 aeson-2.2.2.0-JRwGfw4G4faAdkvjZDffZf
    ansi-terminal-1.1-3WEwGthe7is1LBGeoKnQZb base-4.18.2.1
    bytestring-0.11.5.3 casa-client-0.0.4-5fWMfU44KvyDY9V4yf0nEL
    casa-types-0.0.3-EnegUiIpAX19mTtCxifUL4
    conduit-1.3.6.1-5N1D7XReUYC7Q0FFK7LvDS
    conduit-extra-1.3.8-4QLRWNABAYIHYZwgT1lJOW containers-0.6.7
    crypton-1.0.4-7gnihw9HF3NI2W205N4X1Z
    crypton-conduit-0.2.3-LDSpsxsGOeb1ObeHcScmEq
    digest-0.0.2.1-JWOwjMkQwx5F9nVaVojfVV
    filelock-0.1.1.9-AQsEg2HkzM2J2kr0Gb9jG4
    generic-deriving-1.14.7-IHUaGqqw512L4SmnqdNw4t
    hackage-security-0.6.3.2-3iBalP5XR5o3YAwIvOY5Yh
    hpack-0.38.0-32Y72Klnlpg4AMUHCqIQ9d
    http-client-0.7.19-34xXemB7zi7LDrAIS2UIas
    http-client-tls-0.3.6.4-ADnxKMmkuxZIenWWL3GTLT
    http-conduit-2.3.9.1-1YnFk244Wc91jkGBAdKo7A
    http-download-0.2.1.0-31kNPq7cpYqRURXsRMLQc
    http-types-0.12.4-EqZKGcmXGQgIrxcsE0a1PI
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5 mtl-2.3.1
    network-uri-2.6.4.2-GeBMcWFtBsy42rTUiQRkD3
    path-0.9.6-8SXrQuOX4cO28AjkQwb0Jq
    path-io-1.8.2-I8o8tAy2MBt6SlAUD6Jzoh
    persistent-2.14.6.0-9O6Or4QIlw84QWgPl806Vx
    persistent-sqlite-2.13.2.0-Br1QkHymUpi5CJi7hYvemy
    primitive-0.9.1.0-J4tB0B9QUoG4JNvPWMquph
    resourcet-1.3.0-NkgSS2nOUY5UPO0Rt6LWs
    rio-0.1.24.0-ILFj8o841Gn2vbpIsgWpML
    rio-orphans-0.1.2.0-4Y32WEvrZIk3TJcHJFqJaP
    rio-prettyprint-0.1.8.0-95Dx4oloeFr1EaHroRWsR7
    tar-conduit-0.4.1-FA5O6iJNiuD3KTvga9OYs2 text-2.0.2
    text-metrics-0.3.3-HUyvTH4cT6e403rUaCrtL8 time-1.12.2
    transformers-0.6.1.0 unix-compat-0.7.4.1-4KMmZ8RUI6D4jdDWnXDUAz
    unliftio-0.2.25.1-wbCzY6GGN1Jjb0ZnqHZMi
    unordered-containers-0.2.21-8pZ5d13ZaJk3LfHcqeQHmo
    vector-0.13.2.0-Bce9rIW4lAD9r12sFleKX
    yaml-0.11.11.2-4zqKB1jPXZ171o7QPBTaus
    zip-archive-0.4.3.2-ETDSWh4o3pwBVKmQgtfBqq

haddock-interfaces:   /usr/share/doc/haskell-pantry/html/pantry.haddock
haddock-html:         /usr/share/doc/haskell-pantry/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

